==> bigdata-online-service-api-0.0.92-sources.jar: cn/com/duiba/bigdata/online/service/api/dto/DuibaRiskMergeDto.java <==
package cn.com.duiba.bigdata.online.service.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @author xugf 2019-10-12
 */
@Data
public class DuibaRiskMergeDto implements Serializable {

    private static final long serialVersionUID = -3376062733525573312L;

    //用户活动数据   type = 1
    private DuibaRiskDto consumerActivity;

    //被助力者 type = 18
    private DuibaRiskDto assConsumerActivityNo;

    //用户媒体数据  type = 2
    private DuibaRiskDto consumerApp;

    //用户商品数据  type = 15
    private DuibaRiskDto consumerItem;

    //支付宝数据  type =3
    private DuibaRiskDto alipay;

    //ip5分钟数据  type = 4
    private DuibaRiskDto ipMinute;

    //ip1分钟数据  type = 19
    private DuibaRiskDto ipMinuteOne;

    //ip活动天数据 type = 5
    private DuibaRiskDto ipActivityDay;

    //ip媒体天数据  type = 6
    private DuibaRiskDto ipAppDay;

    //ip商品天数据  type = 16
    private DuibaRiskDto ipItemDay;

    //ip 助力用户 type = 17
    private DuibaRiskDto ipConsumerDay;

    //ip前3段地址活动数据 type = 7
    private DuibaRiskDto ip3Activity;

    //ip前3段地址媒体数据 type = 8
    private DuibaRiskDto ip3App;

    //ua活动 数据  type = 9
    private DuibaRiskDto uaActivity;

    //ua媒体 数据 type = 10
    private DuibaRiskDto uaApp;

    //设备活动天数据 type = 12
    private DuibaRiskDto deviceActivity;

    //设备商品天数据 type = 13
    private DuibaRiskDto deviceItem;

    //设备媒体天数据 type = 11
    private DuibaRiskDto deviceApp;

    //设备用户天粒度 type = 14
    private DuibaRiskDto deviceConsumer;

    //媒体活动 stat type = 20
    private DuibaRiskDto appActivityStat;

    //媒体天  type = 21
    private DuibaRiskDto appStat;


}

==> bigdata-online-service-api-0.0.121-sources.jar: cn/com/duiba/bigdata/online/service/api/dto/DuibaRiskMergeDto.java <==
package cn.com.duiba.bigdata.online.service.api.dto;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @author xugf 2019-10-12
 */
@Data
public class DuibaRiskMergeDto implements Serializable {

    private static final long serialVersionUID = -3376062733525573312L;

    //用户活动数据   type = 1
    private DuibaRiskDto consumerActivity;

    //被助力者 type = 18
    private DuibaRiskDto assConsumerActivityNo;

    //用户媒体数据  type = 2
    private DuibaRiskDto consumerApp;

    //用户商品数据  type = 15
    private DuibaRiskDto consumerItem;

    //支付宝数据  type =3
    private DuibaRiskDto alipay;

    //ip5分钟数据  type = 4
    private DuibaRiskDto ipMinute;

    //ip1分钟数据  type = 19
    private DuibaRiskDto ipMinuteOne;

    //ip活动天数据 type = 5
    private DuibaRiskDto ipActivityDay;

    //ip媒体天数据  type = 6
    private DuibaRiskDto ipAppDay;

    //ip商品天数据  type = 16
    private DuibaRiskDto ipItemDay;

    //ip 助力用户 type = 17
    private DuibaRiskDto ipConsumerDay;

    //ip前3段地址活动数据 type = 7
    private DuibaRiskDto ip3Activity;

    //ip前3段地址媒体数据 type = 8
    private DuibaRiskDto ip3App;

    //ua活动 数据  type = 9
    private DuibaRiskDto uaActivity;

    //ua媒体 数据 type = 10
    private DuibaRiskDto uaApp;

    //设备活动天数据 type = 12
    private DuibaRiskDto deviceActivity;

    //设备商品天数据 type = 13
    private DuibaRiskDto deviceItem;

    //设备媒体天数据 type = 11
    private DuibaRiskDto deviceApp;

    //设备用户天粒度 type = 14
    private DuibaRiskDto deviceConsumer;

    //媒体活动 stat type = 20
    private DuibaRiskDto appActivityStat;

    //媒体天  type = 21
    private DuibaRiskDto appStat;

    //手机号数据  type = 22
    private DuibaRiskDto phoneActivity;

    //第三发账号 type = 23
    private DuibaRiskDto account ;




}
